Willowʼ25
This crate provides concrete parameter choices for the Willow family of specifications, currently:
With choices for the Willow Sideloading Protocol and Willow General Purpose Sync Protocol to follow.
We want it to be easy (and safe!) to start using the various Willow crates, and for there to be an ecosystem of interoperable Willow instances. We’d also like to release this in the year 2025 C.E. Hence, Willowʼ25!
Willowʼ25 uses:
- ed25519 signing and verification provided by
ed25519_dalek - (Temporarily) BLAKE3 cryptographic hashing provided by
blake3. This will eventually be replaced by WILLAM3 cryptographic hashing to allow partial payload verification.
These choices have been chosen to balance performance and cryptographic security. They have not yet been audited in combination with Willow protocols.
Structs
- Authorisation
Token25 - A
meadowcap::McAuthorisationTokensuitable for the Willow Data Model’sAuthorisationTokenparameter. - Namespace
Id25 - Payload
Digest25 - A BLAKE3 hash digest suitable for the Willow Data Model’s
PayloadDigestparameter. - Signature25
- An ed25519 signature suitable for Meadowcap’s
NamespaceSignatureandUserSignatureparameters. - Subspace
Id25 - An ed25519 public key suitable for the Willow Data Model’s
SubspaceIdparameter, and Meadowcap’sUserPublicKeyparameter.
Constants
- MCC25
- A usize for the Willow Data Model’s
max_component_countparameter. - MCL25
- A usize for the Willow Data Model’s
max_component_lengthparameter. - MPL25
- A usize for the Willow Data Model’s
max_component_lengthparameter.
Type Aliases
- Capability25
- A
McCapabilityconfigured with Willowʼ25 parameters.